@@ -26,11 +26,13 @@
 
 """Initialization of the PC Client GUI."""
 
+import platform
 import sys
 import os
 import asyncio
 import argparse
 import datetime
+import signal
 
 import logging
 
@@ -41,6 +43,14 @@ __author__ = 'Bitcraze AB'
 __all__ = []
 
 
+def handle_sigint(app):
+    logging.info('SIGINT received, exiting ...')
+    if app:
+        app.closeAllWindows()
+    else:
+        sys.exit(0)
+
+
 def main():
     """
     Check starting conditions and start GUI.
@@ -49,6 +59,15 @@ def main():
     all imports and exit verbosely if a library is not found. Disable outputs
     to stdout and start the GUI.
     """
+    app = None
+
+    # Connect ctrl-c (SIGINT) signal
+    signal.signal(signal.SIGINT, lambda sig, frame: handle_sigint(app))
+
+    # Allows frozen mac build to load libraries from app bundle
+    if getattr(sys, 'frozen', False) and platform.system() == 'Darwin':
+        os.environ['DYLD_FALLBACK_LIBRARY_PATH'] = os.path.dirname(
+            sys.executable)
 
     # Set ERROR level for PyQt5 logger
     qtlogger = logging.getLogger('PyQt5')
@@ -146,6 +165,9 @@ def main():
     from PyQt5.QtWidgets import QApplication
     from PyQt5.QtGui import QIcon
 
+    if os.name == 'posix':
+        logger.info('If startup fails because of "xcb", install dependency with `sudo apt install libxcb-xinerama0`.')
+
     app = QApplication(sys.argv)
     app.setStyle("Fusion")
     from cfclient.utils.ui import UiUtils
@@ -155,6 +177,7 @@ def main():
     asyncio.set_event_loop(loop)
 
     app.setWindowIcon(QIcon(cfclient.module_path + "/ui/icons/icon-256.png"))
+    app.setApplicationName("Crazyflie client")
     # Make sure the right icon is set in Windows 7+ taskbar
     if os.name == 'nt':
         import ctypes
