@@ -37,8 +37,8 @@ from collections import namedtuple
 import time
 from PyQt5 import uic
 from PyQt5.QtCore import Qt, pyqtSignal, QTimer
-from PyQt5.QtGui import QMessageBox
-from PyQt5.QtGui import QLabel
+from PyQt5.QtWidgets import QMessageBox
+from PyQt5.QtWidgets import QLabel
 
 import cfclient
 from cfclient.ui.tab import Tab
